@@ -92,6 +92,8 @@ from .models.select_expression import SelectExpression
 from .models.source import Source, SourceId, SourceName
 from .models.source_reference import FolderSourceReference
 from .models.table_creation_request import TableCreationRequest, RootTableCreationRequest, ViewTableCreationRequest
+from .models.view_materialisation import *
+from .models.view_materialisation_runs import *
 from . import version
 
 
@@ -969,6 +971,82 @@ class Anaml:
             MergeRequestComment.from_json(r) for r in result
         ]
 
+    # View Materialisation related functions
+    def get_view_materialisations(self) -> List[ViewMaterialisationJob]:
+        """Get a list of all view materialisations from the Anaml server.
+
+        Returns:
+            A list of view materialisations.
+        """
+        r = self._get("/view-materialisation")
+        result = self._json_or_handle_errors(r)
+        return [ViewMaterialisationJob.from_json(r) for r in result]
+
+    def get_view_materialisation_by_id(self, view_materialisation_id: Union[ViewMaterialisationJobId, int]) -> ViewMaterialisationJob:
+        """Get a view materialisation from the Anaml server.
+
+        Args:
+            view_materialisation_id: Unique identifier of the view materialisation.
+
+        Returns:
+            The view materialisation, if it exists.
+        """
+        r = self._get(f"/view-materialisation/{int(view_materialisation_id)}")
+        result = self._json_or_handle_errors(r)
+        return ViewMaterialisationJob.from_json(result)
+
+    def get_view_materialisation_by_name(self, name: Union[ViewMaterialisationJobName, str]) -> ViewMaterialisationJob:
+        """Get a view materialisation from the Anaml server.
+
+        Args:
+            name: Name of the view materialisation.
+
+        Returns:
+            The view materialisation, if it exists.
+        """
+        r = self._get("/view-materialisation", query={'name': str(name)})
+        result = self._json_or_handle_errors(r)
+        return ViewMaterialisationJob.from_json(result)
+
+    def get_view_materialisation_runs(
+        self,
+        view_materialisation_id: Union[ViewMaterialisationJobId, int],
+        num: Optional[int] = None
+    ) -> List[ViewMaterialisationRun]:
+        """Get a list of all runs of a given view materialisation from the Anaml server.
+
+        Args:
+            view_materialisation_id: The unique identifier of a view materialisation.
+            num: Optional. Maximum number of results to return.
+
+        Returns:
+            A list of runs of the given view materialisation.
+        """
+        q = {}
+        if num is not None:
+            q['num'] = num
+        r = self._get(f"/view-materialisation/{int(view_materialisation_id)}/run", query=q)
+        result = self._json_or_handle_errors(r)
+        return [ViewMaterialisationRun.from_json(r) for r in result]
+
+    def get_view_materialisation_run(
+        self,
+        view_materialisation_id: Union[ViewMaterialisationJobId, int],
+        run_id: Union[ViewMaterialisationRunId, int]
+    ) -> ViewMaterialisationRun:
+        """Get the details for a view materialisation run from the Anaml server.
+
+        Args:
+            view_materialisation_id: The unique identifier of a view materialisation.
+            run_id: The unique identifier of a run of that view materialisation.
+
+        Returns:
+             Details of the given view materialisation run.
+        """
+        r = self._get(f"/view-materialisation/{int(view_materialisation_id)}/run/{int(run_id)}")
+        result = self._json_or_handle_errors(r)
+        return ViewMaterialisationRun.from_json(result)
+
     def create_merge_request_comment(
             self,
             merge_request_id: Union[MergeRequestId, int],
